from pydantic import BaseModel
from typing import Optional
from datetime import datetime
import uuid

class WeatherForecastBase(BaseModel):
    location: str
    date: datetime
    temperature: float
    humidity: float
    wind_speed: float
    precipitation_probability: float
    description: str

class WeatherForecastCreate(WeatherForecastBase):
    pass

class WeatherForecastUpdate(WeatherForecastBase):
    location: Optional[str] = None
    date: Optional[datetime] = None
    temperature: Optional[float] = None
    humidity: Optional[float] = None
    wind_speed: Optional[float] = None
    precipitation_probability: Optional[float] = None
    description: Optional[str] = None

class WeatherForecastSchema(WeatherForecastBase):
    id: uuid.UUID
    created_at: datetime
    updated_at: datetime

    class Config:
        orm_mode = True